# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Name:           bsh
Version:        2.1.0
Release:        %mkrel 2
Group:          Development/Java
Epoch:          0
Summary:        Lightweight Scripting for Java
URL:            http://www.beanshell.org/
# bundled asm is BSD
# bsf/src/bsh/util/BeanShellBSFEngine.java is public-domain
License:        ASL 2.0 and BSD and Public Domain

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
# Remove bundled jars which cannot be easily verified for licensing
# Remove code marked as SUN PROPRIETARY/CONFIDENTAIL
Source2:        generate-tarball.sh

# compatibility with Java 11:
# - set javac / javadoc source and target values to 1.8
Patch0:         0000-source-target-1.8.patch
# - remove references to invisible symbols and methods
Patch1:         0001-java-11-compatibility.patch

BuildArch:      noarch

BuildRequires:  ant
BuildRequires:  bsf
BuildRequires:  glassfish-servlet-api
BuildRequires:  javacc
BuildRequires:  javapackages-local
BuildRequires:  junit

Requires:       bsf
Requires:       java-headless
Requires:       jline2

# Explicit javapackages-tools requires since scripts use
# /usr/share/java-utils/java-functions
Requires:       javapackages-tools

Provides:       %{name}-utils = %{epoch}:%{version}-%{release}
Obsoletes:      %{name}-utils < 0:2.0
Obsoletes:      %{name}-demo < 0:2.0

# bsh uses small subset of modified (shaded) classes from ancient version of
# objecweb-asm under asm directory
Provides:       bundled(objectweb-asm) = 1.3.6

%description
BeanShell is a small, free, embeddable, Java source interpreter with
object scripting language features, written in Java. BeanShell
executes standard Java statements and expressions, in addition to
obvious scripting commands and syntax. BeanShell supports scripted
objects as simple method closures like those in Perl and
JavaScript(tm). You can use BeanShell interactively for Java
experimentation and debugging or as a simple scripting engine for your
applications. In short: BeanShell is a dynamically interpreted Java,
plus some useful stuff. Another way to describe it is to say that in
many ways BeanShell is to Java as Tcl/Tk is to C: BeanShell is
embeddable - You can call BeanShell from your Java applications to
execute Java code dynamically at run-time or to provide scripting
extensibility for your applications. Alternatively, you can call your
Java applications and objects from BeanShell; working with Java
objects and APIs dynamically. Since BeanShell is written in Java and
runs in the same space as your application, you can freely pass
references to "real live" objects into scripts and return them as
results.

%package manual
Summary:        Manual for %{name}

%description manual
Documentation for %{name}.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package provides %{summary}.

%prep
%setup -q -n beanshell-%{version}
%patch0 -p1
%patch1 -p1

sed -i 's,org.apache.xalan.xslt.extensions.Redirect,http://xml.apache.org/xalan/redirect,' docs/manual/xsl/*.xsl

%mvn_alias :bsh bsh:bsh bsh:bsh-bsf org.beanshell:bsh

%mvn_file : %{name}

%build
mkdir lib
build-jar-repository lib bsf javacc junit glassfish-servlet-api

ant test dist

%install
%mvn_artifact pom.xml dist/%{name}-%{version}.jar

%mvn_install -J javadoc

install -d -m 755 %{buildroot}%{_datadir}/%{name}
install -d -m 755 %{buildroot}%{_datadir}/%{name}/webapps
install -m 644 dist/bshservlet.war %{buildroot}%{_datadir}/%{name}/webapps
install -m 644 dist/bshservlet-wbsh.war %{buildroot}%{_datadir}/%{name}/webapps

# scripts
install -d %{buildroot}%{_bindir}

%jpackage_script bsh.Interpreter "\${BSH_DEBUG:+-Ddebug=true}" jline.console.internal.ConsoleRunner %{name}:jline2/jline %{name} true
%jpackage_script bsh.Console "\${BSH_DEBUG:+-Ddebug=true}" "" bsh bsh-console true

echo '#!%{_bindir}/bsh' > %{buildroot}%{_bindir}/bshdoc
cat scripts/bshdoc.bsh >> %{buildroot}%{_bindir}/bshdoc

%files -f .mfiles
%license LICENSE NOTICE
%doc README.md src/Changes.html src/CodeMap.html docs/faq/faq.html

%attr(0755,root,root) %{_bindir}/%{name}*
%{_datadir}/%{name}/

%files manual
%doc docs/manual/html
%doc docs/manual/images/*.jpg
%doc docs/manual/images/*.gif
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE



%changelog
* Mon Sep 19 2022 neoclust <neoclust> 0:2.1.0-2.mga9
+ Revision: 1890470
- Fix build with new java

* Sun Feb 28 2021 daviddavid <daviddavid> 0:2.1.0-1.mga9
+ Revision: 1694331
- Update to version 2.1.0
- Change jline Requires to jline2

* Fri Sep 11 2020 daviddavid <daviddavid> 0:2.0-19.b6.1.mga8
+ Revision: 1624403
- Make adjustments for Java 11 compatibility
- Rebuilt for JDK-11

* Fri Feb 14 2020 umeabot <umeabot> 0:2.0-13.b6.2.mga8
+ Revision: 1520721
- Mageia 8 Mass Rebuild

* Wed Dec 05 2018 daviddavid <daviddavid> 0:2.0-13.b6.1.mga7
+ Revision: 1338502
- Remove proprietary files from tarball
- Add requirement on javapackages-tools for script's usage of
  java-functions
- Repack the tarball without binaries

* Thu Sep 20 2018 umeabot <umeabot> 0:2.0-8.b6.2.mga7
+ Revision: 1277784
- Mageia 7 Mass Rebuild

* Wed Oct 04 2017 daviddavid <daviddavid> 0:2.0-8.b6.1.mga7
+ Revision: 1168219
- Update to upstream version 2.0.b6 (sync with fc27)
- Install into expected location
- Build against glassfish-servlet-api
- Fix directory ownership
- Install desktop icon to pixmaps instead of icons
- Add conditional for desktop file
- Properly conditionalize build-requires

* Sun May 14 2017 neoclust <neoclust> 0:1.3.0-37.mga6
+ Revision: 1101248
- Switch to jline 2.x in -utils

* Wed Mar 02 2016 neoclust <neoclust> 0:1.3.0-36.mga6
+ Revision: 982994
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 0:1.3.0-34.mga6
+ Revision: 975690
- First rebuild of the java stack
- sync package bsh with fedora

* Tue Feb 09 2016 umeabot <umeabot> 0:1.3.0-35.mga6
+ Revision: 951900
- Mageia 6 Mass Rebuild

* Sat Jan 10 2015 pterjan <pterjan> 0:1.3.0-34.mga5
+ Revision: 809686
- Sync with Fedora 21

* Wed Oct 15 2014 umeabot <umeabot> 0:1.3.0-33.mga5
+ Revision: 745597
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:1.3.0-32.mga5
+ Revision: 678233
- Mageia 5 Mass Rebuild

* Thu Jan 02 2014 dmorgan <dmorgan> 0:1.3.0-31.mga4
+ Revision: 564010
- Add bsh-core pom

* Sat Oct 19 2013 umeabot <umeabot> 0:1.3.0-30.mga4
+ Revision: 535805
- Mageia 4 Mass Rebuild

* Fri Sep 20 2013 dmorgan <dmorgan> 0:1.3.0-29.mga4
+ Revision: 482605
- Rebuild against new javapackages

* Fri Sep 20 2013 dmorgan <dmorgan> 0:1.3.0-28.mga4
+ Revision: 481815
- Rebuild with hack provide
- Sync spec file with fedora ( cleaning )

* Mon Jul 29 2013 dmorgan <dmorgan> 0:1.3.0-15.mga4
+ Revision: 460258
- Remove ant-trax from BR

* Thu Jan 17 2013 dmorgan <dmorgan> 0:1.3.0-14.mga3
+ Revision: 389007
- Fix vendor

* Fri Jan 11 2013 umeabot <umeabot> 0:1.3.0-13.mga3
+ Revision: 347207
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 0:1.3.0-12.mga3
+ Revision: 324813
- Java Stack Mass Rebuild

* Thu Apr 28 2011 wally <wally> 0:1.3.0-11.0.9.mga1
+ Revision: 92851
- fix desktop file name

* Tue Feb 15 2011 ahmad <ahmad> 0:1.3.0-11.0.8.mga1
+ Revision: 51802
- fix obsoletes

* Mon Jan 24 2011 dmorgan <dmorgan> 0:1.3.0-11.0.7.mga1
+ Revision: 37929
- Submit because of lost rpm

* Mon Jan 24 2011 dmorgan <dmorgan> 0:1.3.0-11.0.6.mga1
+ Revision: 37925
- Submit because of lost rpm

* Wed Jan 19 2011 dmorgan <dmorgan> 0:1.3.0-11.0.5.mga1
+ Revision: 24597
- Do not build doc for now
- Fix BuildRequires
- Sync with fedora
- imported package bsh


* Fri May 23 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.3.0-11.0.4mdv2009.0
+ Revision: 210153
- remove gnu-crypto references and disable gcj_support

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:1.3.0-11.0.4mdv2008.1
+ Revision: 120806
- buildrequires java-rpmbuild

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:1.3.0-11.0.3mdv2008.0
+ Revision: 87263
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Wed Sep 05 2007 David Walluck <walluck@mandriva.org> 0:1.3.0-11.0.2mdv2008.0
+ Revision: 79666
- add javadoc link
- fix maven dir ownership
- fix gcj scriptlets
- remove file requires

* Tue Aug 28 2007 David Walluck <walluck@mandriva.org> 0:1.3.0-11.0.1mdv2008.0
+ Revision: 72560
- link to bsf
- fix Vendor and Distribution
- sync with jpackage
- Import bsh



* Mon Aug 07 2006 David Walluck <walluck@mandriva.org> 0:1.3.0-9.1.1mdv2007.0
- update and rebuild

* Mon Jun 05 2006 David Walluck <walluck@mandriva.org> 0:1.3.0-6.3mdv2007.0
- rebuild for libgcj.so.7
- own %%{_libdir}/gcj/%%{name}

* Fri Dec 02 2005 David Walluck <walluck@mandriva.org> 0:1.3.0-6.2mdk
- add post scripts

* Fri Dec 02 2005 David Walluck <walluck@mandriva.org> 0:1.3.0-6.1mdk
- aot-compile

* Sat Sep 10 2005 David Walluck <walluck@mandriva.org> 0:1.3.0-5.1mdk
- release

* Thu Jun 16 2005 Gary Benson <gbenson@redhat.com> 0:1.3.0-5jpp_1fc
- Build into Fedora.

* Thu Mar  4 2004 Frank Ch. Eigler <fche@redhat.com> 0:1.3.0-5jpp_1rh
- RH vacuuming
- added bsf build-prereq

* Mon Jan 26 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-5jpp
- really drop readline..patch

* Sun Jan 25 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-4jpp
- drop readline..patch

* Wed Jan 21 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-3jpp
- port libreadline-java patch to new bsh

* Tue Jan 20 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-2jpp
- add Distribution tag

* Tue Jan 20 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-1jpp
- 1.3.0
- remove bsf patch (fixed upstream)
- add epoch to demo package Requires

* Fri Apr 12 2003 David Walluck <david@anti-microsoft.org> 0:1.2-0.b8.4jpp
- fix strange permissions

* Fri Apr 11 2003 David Walluck <david@anti-microsoft.org> 0:1.2-0.b8.3jpp
- rebuild for JPackage 1.5
- add bsf..patch

* Sat Feb 01 2003 David Walluck <david@anti-microsoft.org> 1.2-0.b8.2jpp
- remove servlet dependency (if anyone wants to add this as a separate
  package and do the tomcat integration, be my guest)

* Thu Jan 23 2003 David Walluck <david@anti-microsoft.org> 1.2-0.b8.1jpp
- rename to bsh
- add manual
- add Changes.html to %%doc
- add bsh and bshdoc scripts
- add %%dir %%{_datadir}/%%{name} to main package
- correct test interpreter and make bsh files executable

* Mon Jan 21 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.01-3jpp
- really section macro

* Sun Jan 20 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.01-2jpp
- additional sources in individual archives
- versioned dir for javadoc
- no dependencies for javadoc package
- stricter dependency for demo package
- section macro

* Tue Dec 18 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.01-1jpp
- first JPackage release
